<?php 
include ("slooze_local.php");
lang_init();
page_open(array("sess" => "Tof_Session",
				"auth" => "Tof_Auth")); 

$tof = new MySlooze($auth->auth['uid']);
$tof->setAdmin(true);
$render = new BasicRender($tof);
$tof->setRender($render);

require_once("render/page.php");

if ($auth->auth['uid'] === "" || $auth->auth['uid'] === 0 || $auth->auth['uid'] == 'nobody') {
	$render->error(
		sprintf(
			_("In order to access the admin pages, you must <a href=\"%s\">login.</a>"),
			"$PHP_SELF?again=yes"));
	renderMessagePage($render,$vars,$PHP_SELF);
} else {
	$vars = $tof->validateInputs();
	$tof->handleAction($vars);
	renderPage($render,$vars,$PHP_SELF);
}

page_close();
?>
